@@ -31,7 +31,7 @@ Archive::SevenZip - Read/write 7z , zip , ISO9960 and other archives
 
 =cut
 
-our $VERSION= '0.08';
+our $VERSION= '0.09';
 
 # Archive::Zip API
 # Error codes
@@ -72,7 +72,7 @@ our %sevenzip_stdin_support = (
     'bzip2' => 1,
 );
 
-if( $^O !~ /MSWin/ ) {
+if( $^O !~ /MSWin/i ) {
     # Wipe all filesystem encodings because my Debian 7z 9.20 doesn't understand them
     $sevenzip_charsetname{ $_ } = ''
         for keys %sevenzip_charsetname;
@@ -83,6 +83,7 @@ our %class_defaults = (
     fs_encoding => 'UTF-8',
     default_options => [ "-y", "-bd" ],
     type => 'zip',
+    system_needs_quotes => ($^O =~ /MSWin/i)
 );
 
 =head2 C<< Archive::SevenZip->find_7z_executable >>
@@ -410,9 +411,13 @@ sub removeMember {
 };
 
 sub add_quotes {
-    map {
-        defined $_ && /\s/ ? qq{"$_"} : $_
-    } @_
+    my $quote = shift;
+
+    $quote ?
+        map {
+            defined $_ && /\s/ ? qq{"$_"} : $_
+        } @_
+    : @_
 };
 
 sub get_command {
@@ -443,15 +448,16 @@ sub get_command {
     for( @{ $options{ options }}, @{ $options{ members }}, $options{ archivename }, "$self->{ '7zip' }") {
     };
 
+    my $add_quote = $self->{system_needs_quotes};
     return [grep {defined $_}
-        add_quotes($self->{ '7zip' }),
+        add_quotes($add_quote, $self->{ '7zip' }),
         @{ $options{ default_options }},
         $options{ command },
         @charset,
-        add_quotes( @{ $options{ options }} ),
+        add_quotes($add_quote, @{ $options{ options }} ),
         "--",
-        add_quotes( $options{ archivename } ),
-        add_quotes( @{ $options{ members }} ),
+        add_quotes($add_quote, $options{ archivename } ),
+        add_quotes($add_quote, @{ $options{ members }} ),
     ];
 }
 
